library(ggplot2)
library(lmodel2)
library(effects)
library(gplots)

setwd("C:/Users/Administrator/Desktop/Files/CODE_DATA")


#############
###################  Figure. 2  
#############

Clim<-read.csv("Cli.csv",header=T)#####   CLIMATES DATA.

########
############   2-A  Temperature
#######

tgc <- summarySE(Clim, measurevar="T", groupvars=c("Population","Month"))
 
ggplot(Clim, aes(x=Month,y=T,group=Population,shape=Population)) + 
  geom_errorbar(aes(ymin=T-TSE, ymax=T+TSE), colour="black", width=0.1)+
  geom_line(size=0.8) + geom_point(size=2.5)+ 
  scale_x_continuous(breaks=seq(0, 12, 1),expand=c(0,0))+
  xlab(" ") + ylab(" ")+
  scale_y_continuous(expand=c(0,0))+
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=16),legend.background=element_rect(fill="white"),
        legend.position=c(0.1,0.96),
        legend.key=element_rect(fill="white",size=4),
        axis.text.x = element_text(margin=margin(6,6,8,6,"pt")),
        axis.text.y = element_text(margin=margin(6,6,8,6,"pt")))

########
############   2-B  Rainfall
#######

ggplot(Clim, aes(x=Month,y=Rain,group=Population,shape=Population)) + 
  scale_x_continuous(breaks=seq(0, 12, 1),expand=c(0,0))+
  scale_y_continuous(expand=c(0,0))+  geom_line(size=0.8) + geom_point(size=2.5)+
  xlab(" ") + ylab(" ")+ 
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=16),legend.background=element_rect(fill="white"),
        legend.position=c(0.1,0.96),
        legend.key=element_rect(fill="white",size=4),
        axis.text.x = element_text(margin=margin(6,6,8,6,"pt")),
        axis.text.y = element_text(margin=margin(6,6,8,6,"pt")))



bartlett.test(SVL~GRO,data=FEMALE)
shapiro.test(FEMALE$SVL)
bartlett.test(TBW~GRO,data=FEMALE)
shapiro.test(FEMALE$TBW)

#############
###################  Figure. 3 
#############



FEMALE<-read.csv("FEMALE.csv",header=TRUE) ###### Female Morphology data

########
############   Statistic  SVL
#######

aovsvl<-aov(SVL~GRO,data=FEMALE)
summary(aov(SVL~GRO,data=FEMALE)) 
summary(lm(SVL~GRO,data=FEMALE))  

########
############   Statistic  TBW
#######

TBW1<-aov(TBW~GRO+SVL,data=FEMALE)
summary(TBW1)
TukeyHSD(TBW1,"GRO",ordered=TRUE)
summary(lm(TBW~GRO+SVL,data=FEMALE))

########
############   pic 3-A SVL
#######

par(mar= c(3.4,3.4,0.6,0.6))
plotmeans(FEMALE$SVL~FEMALE$GRO,xaxt="n",yaxs ="i",xlab="",ylab=" ",
          n.label=F,pch=16,ylim=c(45,53),tck=0.01,cex.axis=1.5,
          cex=1.5,bty="l",connect=F,col="black", barwidth=1,barcol="black")

########
############   pic 3-B TBW
#######

plotmeans(FEMALE$TBW~FEMALE$GRO,xaxt="n",yaxs ="i",xlab="",ylab=" ",
          n.label=F,pch=16,ylim=c(6.5,8.1),tck=0.01,cex.axis=1.5,
          cex=1.5,bty="l",connect=F,col="black", barwidth=1,barcol="black")


#############
###################  Table 1
#############

hb<-read.csv("HB.csv",header=TRUE) ##### eggs data of three population

bartlett.test(em4~gro4,data=hb)
shapiro.test(hb$em4)
em1<-aov(em4~gro4,data=hb)
summary(aov(em4~gro4,data=hb))
summary(lm(em4~gro4,data=hb))
TukeyHSD(em1,"gro4",ordered = TRUE)

bartlett.test(es4~gro4,data=hb)
shapiro.test(hb$es4)
es1<-aov(es4~gro4,data=hb)
summary(es1)
summary(lm(es4~gro4,data=hb))
TukeyHSD(es1,"gro4",ordered = TRUE)

bartlett.test(el4~gro4,data=hb)
shapiro.test(hb$es4)
el1<-aov(el4~gro4+em4,data=hb)
summary(el1)
TukeyHSD(el1, "gro4", ordered = TRUE)
effect("gro4",el1)

bartlett.test(ew4~gro4,data=hb)
shapiro.test(hb$es4)
ew1<-aov(ew4~gro4+em4,data=hb)
summary(ew1)
TukeyHSD(ew1,"gro4", ordered=TRUE)
effect("gro4",ew1)

cs<-read.csv("CS.csv",header=TRUE)### data of cs of 3 popullations

bartlett.test(cs4~gro4,data=hb)
shapiro.test(hb$es4)
cs1<-aov(cs4~gro4+svl4,data=cs)
summary(cs1)
TukeyHSD(cs1,"gro4",ordered = TRUE)
effect("gro4",cs1)

#############
###################  Figure 4
#############

B_e<-read.csv("BTeggs.csv",header=TRUE)##BT DATA
F_e<-read.csv("FYeggs.csv",header=TRUE)##FY DATA
Y_e<-read.csv("YNeggs.csv",header=TRUE)##YN DATA

lmodel2(em1~cs1,data=B_e) ## intercept= 0.86   slope= -0.12  R^2=0.36  P<0.01
lmodel2(em2~cs2,data=F_e) ## intercept= 1.19   slope= -0.15  R^2=0.27  P<0.01
lmodel2(em3~cs3,data=Y_e) ##  P>0.05
lmodel2(el1~cs1,data=B_e) ## intercept=20.40  slope=-1.89   R^2=0.12  P<0.05
lmodel2(el2~cs2,data=F_e) ## intercept=22.24  slope=-1.88   R^2=0.30  P<0.01
lmodel2(el3~cs3,data=Y_e) ##  P>0.05
lmodel2(el1~em1,data=B_e) ## intercept=7.18   slope=15.31   R^2=0.52  P<0.01
lmodel2(el2~em2,data=F_e) ## intercept=6.89   slope=12.94   R^2=0.80  P<0.01
lmodel2(el3~em3,data=Y_e) ## intercept=8.24   slope=11.67   R^2=0.60  P<0.01


##### 4-A  EM-CS
ggplot(hb, aes(x =cs4,y=em4,group=Population,shape=Population)) + 
  scale_shape_manual(values=c(8,17,2))+
  scale_x_continuous(limits=c(1,7),expand=c(0,0))+
  scale_y_continuous(limits=c(0.2,1.2),expand=c(0,0))+
  xlab(" ") + ylab(" ")+geom_jitter(size=2.5,width=0.25)+
  geom_abline(intercept=0.86,slope=-0.12,linetype=3,size=1,show.legend = NA)+
  geom_abline(intercept=1.19,slope=-0.15,size=1,show.legend = NA,linetype=2)+
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=18),legend.position="none",
        legend.key=element_rect(fill="white"),
        axis.text.x = element_text(margin=margin(8,0,0,0,"pt"),hjust=0.8),
        axis.text.y = element_text(margin=margin(0,6,0,0,"pt")))

######legend
plot(1:10,1:10,col="white")
legend("topleft",bty = "n",inset=0.05, cex=1.5,legend=c("BT","FY","YN"),lty=c(3,2,NA), pch=c(8,17,2),col=c("black","black","black"))

### 4-B -  ELCS

ggplot(hb, aes(x=cs4,y=el4,group=Population,shape=Population)) + 
  scale_shape_manual(values=c(8,17,2))+
  scale_x_continuous(limits=c(1,7),expand=c(0,0))+
  scale_y_continuous(limits=c(9,21),expand=c(0,0))+
  xlab("") + ylab("")+geom_jitter(size=2.5,width=0.25)+
  geom_abline(intercept=20.40,slope=-1.89,size=1,linetype=3)+
  geom_abline(intercept=22.24,slope=-1.88,size=1,linetype=2)+
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=18),legend.position="none",
        axis.text.x = element_text(margin=margin(8,0,0,0,"pt"),hjust=0.8),
        axis.text.y = element_text(margin=margin(0,6,0,0,"pt")))

### 4-C -  EL   -  EM

ggplot(hb, aes(x=em4,y=el4,group=Population,shape=Population)) + 
  scale_shape_manual(values=c(8,17,2))+
  scale_x_continuous(limits=c(0.2,1.2),expand=c(0,0))+ 
  scale_y_continuous(limits=c(9,21),expand=c(0,0))+
  xlab(" ") + ylab(" ")+ geom_jitter(size=2.5)+
  geom_abline(intercept=7.18,slope=15.31,size=1,linetype=3)+
  geom_abline(intercept=6.89,slope=12.94,size=1,linetype=2)+
  geom_abline(intercept=8.24,slope=11.68,size=1,linetype=1)+
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=18),legend.position="none",
        legend.key=element_rect(fill="white",size=4),
        axis.text.x = element_text(margin=margin(8,0,0,0,"pt"),hjust=0.8),
        axis.text.y = element_text(margin=margin(0,6,0,0,"pt")))

######legend
plot(1:10,1:10,col="white")
legend("topleft",bty = "n",inset=0.05, cex=1.5,legend=c("BT","FY","YN"),lty=c(3,2,1), pch=c(8,17,2),col=c("black","black","black"))

#############
###################  Figure 5
#############

lmodel2(el1~log10(svl1),data=B_e)## P>0.05
lmodel2(el2~log10(svl2),data=F_e)## P>0.05
lmodel2(el3~log10(svl3),data=Y_e)## intercept=-72.98   slope= 51.31  R^2=0.08  P<0.05
lmodel2(ew1~tbw1,data=B_e)## P>0.05
lmodel2(ew2~tbw2,data=F_e)## P>0.05
lmodel2(ew3~tbw3,data=Y_e)## intercept=3.11   slope=0.72  R^2=0.13  P<0.01

B_c<-read.csv("BTcs.csv",header=TRUE)##BT DATA
F_c<-read.csv("FYcs.csv",header=TRUE)##FY DATA
Y_c<-read.csv("YNcs.csv",header=TRUE)##YN DATA

lmodel2(cs1~log10(svl1),data=B_c)## P>0.05
lmodel2(cs2~log10(svl2),data=F_c)## P>0.05
lmodel2(cs3~log10(svl3),data=Y_c)## P>0.05

##  FIGURE 5A

ggplot(hb, aes(x=log10(svl4),y=el4,group=Population,shape=Population)) + 
  scale_shape_manual(values=c(8,17,2))+
  scale_x_continuous(limits=c(1.625,1.75),expand=c(0,0))+ 
  scale_y_continuous(limits=c(9,21),expand=c(0,0))+
  xlab(" ") + ylab(" ")+ geom_jitter(size=2.5)+
  geom_abline(intercept=-72.99,slope=51.31,size=1,linetype=1)+
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=18),legend.position="none",
        legend.key=element_rect(fill="white",size=4),
        axis.text.x = element_text(margin=margin(8,0,0,0,"pt"),hjust=0.9),
        axis.text.y = element_text(margin=margin(0,6,0,0,"pt")))

######legend
plot(1:10,1:10,col="white")
legend("topleft",bty = "n",inset=0.05, cex=1.5,legend=c("BT","FY","YN"),lty=c(NA,NA,1), pch=c(8,17,2),col=c("black","black","black"))

#WIDTH

#   FIGURE 5B

ggplot(hb, aes(x=tbw4,y=ew4,group=Population,shape=Population)) + 
  scale_shape_manual(values=c(8,17,2))+
  xlab(" ") + ylab(" ")+ geom_jitter(size=2.5)+
  scale_x_continuous(limits=c(5,9),expand=c(0,0))+ 
  scale_y_continuous(limits=c(6,11),expand=c(0,0))+
  geom_abline(intercept=3.11,slope=0.72,size=1,linetype=1)+
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=18),legend.position="none",
        legend.key=element_rect(fill="white",size=4),
        axis.text.x = element_text(margin=margin(10,0,0,0,"pt"),hjust=0.9),
        axis.text.y = element_text(margin=margin(0,6,0,0,"pt")))

#   FIGURE 5C
ggplot(cs, aes(x=log10(svl4),y=cs4,group=Population,shape=Population))+
  scale_shape_manual(values=c(8,17,2))+
  xlab(" ") + ylab(" ")+ geom_jitter(size=2.5,height = 0.14)+
  scale_x_continuous(limits=c(1.625,1.75),expand=c(0,0))+ 
  scale_y_continuous(limits=c(1,7),expand=c(0,0))+
  theme(panel.grid.major =element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),axis.line = element_line(colour = "black"),
        axis.ticks.length = unit(-0.3,"line"))+
  theme(axis.text=element_text(size=18),legend.position="none",
        legend.key=element_rect(fill="white",size=4),
        axis.text.x = element_text(margin=margin(10,0,0,0,"pt"),hjust=0.7),
        axis.text.y = element_text(margin=margin(0,6,0,0,"pt")))


######legend
plot(1:10,1:10,col="white")
legend("topleft",bty = "n",inset=0.05, cex=1.5,legend=c("BT","FY","YN"),pch=c(8,17,2),col=c("black","black","black"))
